@@ -26,6 +26,8 @@ func TestRegisterBasic(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
@@ -119,6 +121,9 @@ func TestRegisterBadServer(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
+
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
@@ -263,6 +268,9 @@ func TestRegisterNegative(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
+
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
@@ -313,6 +321,9 @@ func TestGenerateCerts(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
+
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
@@ -370,6 +381,9 @@ func TestWriteAgentTokenFileDuringRegistration(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
+
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
@@ -464,6 +478,9 @@ func TestRepeatRegister(t *testing.T) {
 	os.Mkdir(path.Join(tmpDir, "tokens"), 0755)
 
 	// redefined consts with paths to cert files
+	restoreCerts := RememberCertPaths()
+	defer restoreCerts()
+
 	KeyPEMFile = path.Join(tmpDir, "certs/key.pem")
 	CertPEMFile = path.Join(tmpDir, "certs/cert.pem")
 	RootCAFile = path.Join(tmpDir, "certs/ca.pem")
