@@ -107,13 +107,17 @@ func runDBMigrate(settings *cli.Context, command, version string) {
 }
 
 // Execute cert export command.
-func runCertExport(settings *cli.Context) {
+func runCertExport(settings *cli.Context) error {
 	db := getDBConn(settings)
 
-	err := certs.ExportSecret(db, settings.String("object"), settings.String("file"))
-	if err != nil {
-		log.Fatalf("unable to export: %s", err)
-	}
+	return certs.ExportSecret(db, settings.String("object"), settings.String("file"))
+}
+
+// Execute cert import command.
+func runCertImport(settings *cli.Context) error {
+	db := getDBConn(settings)
+
+	return certs.ImportSecret(db, settings.String("object"), settings.String("file"))
 }
 
 // Prepare urfave cli app with all flags and commands defined.
@@ -126,45 +130,45 @@ func setupApp() *cli.App {
 		&cli.StringFlag{
 			Name:    "db-url",
 			Usage:   "The URL to locate Stork PostgreSQL database.",
-			EnvVars: []string{"STORK_TOOL_DB_URL"},
+			EnvVars: []string{"STORK_DATABASE_URL"},
 		},
 		&cli.StringFlag{
 			Name:    "db-user",
 			Usage:   "The user name to be used for database connections.",
 			Aliases: []string{"u"},
 			Value:   "stork",
-			EnvVars: []string{"STORK_TOOL_DB_USER"},
+			EnvVars: []string{"STORK_DATABASE_USER_NAME"},
 		},
 		&cli.StringFlag{
 			Name:    "db-password",
 			Usage:   "The database password to be used for database connections.",
-			EnvVars: []string{"STORK_TOOL_DB_PASSWORD"},
+			EnvVars: []string{"STORK_DATABASE_PASSWORD"},
 		},
 		&cli.StringFlag{
 			Name:    "db-host",
 			Usage:   "The name of the host where the database is available.",
 			Value:   "localhost",
-			EnvVars: []string{"STORK_TOOL_DB_HOST"},
+			EnvVars: []string{"STORK_DATABASE_HOST"},
 		},
 		&cli.StringFlag{
 			Name:    "db-port",
 			Usage:   "The port on which the database is available.",
 			Aliases: []string{"p"},
 			Value:   "5432",
-			EnvVars: []string{"STORK_TOOL_DB_PORT"},
+			EnvVars: []string{"STORK_DATABASE_PORT"},
 		},
 		&cli.StringFlag{
 			Name:    "db-name",
 			Usage:   "The name of the database to connect to.",
 			Aliases: []string{"d"},
 			Value:   "stork",
-			EnvVars: []string{"STORK_TOOL_DB_NAME"},
+			EnvVars: []string{"STORK_DATABASE_NAME"},
 		},
 		&cli.StringFlag{
 			Name:    "db-trace-queries",
 			Usage:   "Enable tracing SQL queries: \"run\" - only run-time, without migrations, \"all\" - migrations and run-time.",
 			Value:   "",
-			EnvVars: []string{"STORK_TOOL_DB_TRACE_QUERIES"},
+			EnvVars: []string{"STORK_DATABASE_TRACE_QUERIES"},
 		},
 	}
 
@@ -186,11 +190,26 @@ func setupApp() *cli.App {
 		},
 		&cli.StringFlag{
 			Name:    "file",
-			Usage:   "The file location where the object should be saved.",
+			Usage:   "The file location where the object should be saved. If not provided then object is printed to stdout.",
 			Aliases: []string{"o"},
 			EnvVars: []string{"STORK_TOOL_CERT_FILE"},
 		})
 
+	certImportFlags := append(dbFlags,
+		&cli.StringFlag{
+			Name:     "object",
+			Usage:    "The object to dump, it can be one of 'cakey', 'cacert', 'srvkey', 'srvcert', 'srvtkn'.",
+			Required: true,
+			Aliases:  []string{"f"},
+			EnvVars:  []string{"STORK_TOOL_CERT_OBJECT"},
+		},
+		&cli.StringFlag{
+			Name:    "file",
+			Usage:   "The file location from which the object will be read. If not provided then the object is read from stdin.",
+			Aliases: []string{"i"},
+			EnvVars: []string{"STORK_TOOL_CERT_FILE"},
+		})
+
 	app := &cli.App{
 		Name: "Stork Tool",
 		Usage: `A tool for managing Stork Server
@@ -287,10 +306,16 @@ func setupApp() *cli.App {
 				Description: ``,
 				Flags:       certExportFlags,
 				Category:    "Certificates Management",
-				Action: func(c *cli.Context) error {
-					runCertExport(c)
-					return nil
-				},
+				Action:      runCertExport,
+			},
+			{
+				Name:        "cert-import",
+				Usage:       "Import certificate or other secret data",
+				UsageText:   "stork-tool cert-import [options for db connecion] [-f object] [-i filename]",
+				Description: ``,
+				Flags:       certImportFlags,
+				Category:    "Certificates Management",
+				Action:      runCertImport,
 			},
 		},
 	}
