@@ -1,3 +1,4 @@
+import os
 import time
 import xmlrpc.client
 import subprocess
@@ -5,11 +6,11 @@ import subprocess
 import pytest
 
 import containers
-from containers import KEA_1_6, KEA_LATEST
+from containers import KEA_1_6, KEA_LATEST, KeaTLSSupport
 
 SUPPORTED_DISTROS = [
-    ('ubuntu/18.04', 'centos/7'),
-    ('centos/7', 'ubuntu/18.04')
+    ('ubuntu/18.04', 'centos/8'),
+    ('centos/8', 'ubuntu/18.04')
 ]
 
 
@@ -55,8 +56,41 @@ def _get_machines_and_authorize_them(server, expected_items=1):
 
 
 def _get_machine_state(server, m_id):
+    '''We have a hard to resolve race problem with update machine state in the Stork.
+    The problem occurs when the Stork tries refreshing an application state from multiple goroutines at the same time.
+
+    Refresh may be triggered by:
+
+    - On Stork start
+    - Periodically
+    - On user request
+
+    Some refresh procedures may be called in the same time.
+    Refresh state looks like this:
+
+        1. Get state from an agent
+        2. Get state from a database
+        3. Calculate diff
+        4. Provide changes in the application
+        5. Provide changes in the subnets and others
+
+    Points 2, 4, and 5 are done in a separate transaction.
+    It may happen that after fetching state from the database (2.) and calculate diffs (3.) in one goroutine,
+    another goroutine modified the application. It causes that the calculated diffs are incorrect.
+    The exception is thrown from point 4. where the unique index constraints are checked.
+    If exception is thrown then it means that the insert conflict may occur.
+    Another goroutine could correctly insert the state.
+    '''
+    error_attempts = 0
     for i in range(100):
-        r = server.api_get('/machines/%d/state' % m_id)
+        try:
+            r = server.api_get('/machines/%d/state' % m_id)
+        except Exception:
+            if error_attempts < 3:
+                error_attempts += 1
+                time.sleep(5)
+                continue
+
         data = r.json()
         if data['apps'] and data['apps'][0]['details']:
             break
@@ -192,7 +226,7 @@ def test_pkg_upgrade_server_token(distro_agent, distro_server):
     assert m['apps'][0]['version'] == KEA_LATEST.split('-')[0]
 
 
-@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/7')])
+@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/8')])
 def test_add_kea_with_many_subnets(agent, server):
     """Check if Stork agent and server will handle Kea instance with huge amount of subnets."""
     # install kea on the agent machine
@@ -215,6 +249,7 @@ def test_add_kea_with_many_subnets(agent, server):
 
     # check machine state
     m = _get_machine_state(server, m['id'])
+
     assert m['apps'] is not None
     assert len(m['apps']) == 1
     assert m['apps'][0]['version'] == KEA_LATEST.split('-')[0]
@@ -230,6 +265,8 @@ def test_add_kea_with_many_subnets(agent, server):
         if 'total' in data and data['total'] == 6912:
             break
         time.sleep(2)
+        # Fetch new state
+        m = _get_machine_state(server, m['id'])
     assert data['total'] == 6912
 
     # Fetch raw Kea daemon configuration
@@ -250,10 +287,10 @@ def test_add_kea_with_many_subnets(agent, server):
     # assert len(subnets) == 6912
 
 
-def _wait_for_event(server, text):
+def _wait_for_event(server, text, expected=True, attempts=20):
     last_ts = None
     event_occured = False
-    for i in range(20):
+    for i in range(attempts):
         r = server.api_get('/events')
         data = r.json()
         for ev in reversed(data['items']):
@@ -267,7 +304,8 @@ def _wait_for_event(server, text):
             break
         last_ts = data['items'][0]['createdAt']
         time.sleep(2)
-    assert event_occured, 'no event about `%s`' % text
+
+    assert event_occured == expected, ('no' if expected else 'found') + ' event about `%s`' % text
 
 def _search_leases(server, text=None, host_id=None):
     assert text != None or host_id != None
@@ -292,8 +330,7 @@ def _search_leases(server, text=None, host_id=None):
 
     return data['items'], None
 
-
-@pytest.mark.parametrize("agent, server", [('centos/7', 'ubuntu/18.04')])
+@pytest.mark.parametrize("agent, server", [('centos/8', 'ubuntu/18.04')])
 def test_change_kea_ca_access_point(agent, server):
     """Check if Stork server notices that Kea CA has changed its listening address."""
     # install kea on the agent machine
@@ -311,7 +348,7 @@ def test_change_kea_ca_access_point(agent, server):
     m = _get_machine_state(server, m['id'])
     assert m['apps'] is not None
     assert len(m['apps']) == 1
-    assert m['apps'][0]['version'] == '1.8.0'
+    assert m['apps'][0]['version'] == KEA_LATEST.split('-')[0]
     assert len(m['apps'][0]['accessPoints']) == 1
     assert m['apps'][0]['accessPoints'][0]['address'] == '127.0.0.1'
 
@@ -343,7 +380,7 @@ def test_change_kea_ca_access_point(agent, server):
     assert m['apps'][0]['accessPoints'][0]['address'] == agent.mgmt_ip
 
 
-@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/7')])
+@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/8')])
 def test_search_leases(agent, server):
     # Install Kea on the machine with a Stork Agent.
     agent.install_kea()
@@ -450,7 +487,7 @@ def run_perfdhcp(src_cntr, dest_ip_addr):
         raise Exception('perfdhcp erred: %s' % str(result))
 
 
-@pytest.mark.parametrize("agent_kea, agent_old_kea, server", [('ubuntu/20.04', 'ubuntu/18.04', 'centos/7')])
+@pytest.mark.parametrize("agent_kea, agent_old_kea, server", [('ubuntu/20.04', 'ubuntu/18.04', 'centos/8')])
 def test_get_kea_stats(agent_kea, agent_old_kea, server):
     """Check if collecting stats from various Kea versions works.
        DHCPv4 traffic is send to old Kea, then to new kea
@@ -553,16 +590,16 @@ def test_get_kea_stats(agent_kea, agent_old_kea, server):
     assert sn_with_addrs == 2
 
 
-@pytest.mark.parametrize("agent, server, bind_version", [('centos/7', 'ubuntu/18.04', None),
-                                                         ('centos/7', 'ubuntu/18.04', '9.11'),
-                                                         ('centos/7', 'ubuntu/18.04', '9.16'),
-                                                         ('centos/7', 'ubuntu/18.04', '9.17'),
+@pytest.mark.parametrize("agent, server, bind_version", [('centos/8', 'ubuntu/18.04', None),
+                                                         ('centos/8', 'ubuntu/18.04', '9.11'),
+                                                         ('centos/8', 'ubuntu/18.04', '9.16'),
+                                                         ('centos/8', 'ubuntu/18.04', '9.17'),
                                                          ('centos/8', 'ubuntu/18.04', None),
-                                                         ('ubuntu/18.04', 'centos/7', None),
-                                                         ('ubuntu/18.04', 'centos/7', '9.11'),
-                                                         ('ubuntu/18.04', 'centos/7', '9.16'),
-                                                         ('ubuntu/18.04', 'centos/7', '9.17'),
-                                                         ('ubuntu/20.04', 'centos/7', None)])
+                                                         ('ubuntu/18.04', 'centos/8', None),
+                                                         ('ubuntu/18.04', 'centos/8', '9.11'),
+                                                         ('ubuntu/18.04', 'centos/8', '9.16'),
+                                                         ('ubuntu/18.04', 'centos/8', '9.17'),
+                                                         ('ubuntu/20.04', 'centos/8', None)])
 def test_bind9_versions(agent, server, bind_version):
     """Check if Stork agent detects different BIND 9 versions."""
     # install kea on the agent machine
@@ -585,7 +622,7 @@ def test_bind9_versions(agent, server, bind_version):
     assert m['apps'][0]['accessPoints'][0]['address'] == '127.0.0.1'
 
 
-@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/7')])
+@pytest.mark.parametrize("agent, server", [('ubuntu/18.04', 'centos/8')])
 def test_get_host_leases(agent, server):
     # Install Kea on the machine with a Stork Agent.
     agent.install_kea()
@@ -654,7 +691,7 @@ def test_get_host_leases(agent, server):
 
     # Find leases for the IPv6 host reservation.
     leases, conflicts = _search_leases(server, host_id=host_id)
-    assert len(leases) is 1
+    assert len(leases) == 1
     assert 'ipAddress' in leases[0]
     assert leases[0]['ipAddress'] == '3001:db8:1::2'
 
@@ -719,3 +756,77 @@ def test_agent_reregistration_after_restart(agent, server):
     # the agent token and cert files should be the same as before restart
     assert agent_token_before == agent_token_after
     assert tuple(hashes_before) == tuple(hashes_after)
+
+@pytest.mark.parametrize("agent, server", [('centos/8', 'ubuntu/18.04')])
+def test_communication_with_kea_over_secure_protocol(agent, server):
+    """Check if Stork agent communicates with Kea over HTTPS correctly.
+    In this test the Kea doesn't require SSL certificate on the client side."""
+    # install kea on the agent machine
+    agent.set_skip_tls_cert_verification()
+    agent.install_kea(tls_support=KeaTLSSupport.OPTIONAL_CLIENT_CERT)
+
+    # login
+    r = server.api_post('/sessions', json=dict(useremail='admin', userpassword='admin'), expected_status=200)  # TODO: POST should return 201
+    assert r.json()['login'] == 'admin'
+
+    # get machine that automatically registered in the server and authorize it
+    m = _get_machines_and_authorize_them(server)[0]
+    # trig forward command to Kea over HTTPS
+    m = _get_machine_state(server, m['id'])
+
+    assert m['address'] == agent.mgmt_ip
+    assert m['apps'][0]['accessPoints'][0]['useSecureProtocol']
+
+    # Stork Agent should correctly connect to the Kea CA.
+    # No error can occur.
+    _wait_for_event(server, 'Failed to forward commands to Kea', expected=False)
+
+
+@pytest.mark.parametrize("agent, server", [('centos/8', 'ubuntu/18.04')])
+def test_communication_with_kea_over_secure_protocol_nontrusted_client(agent, server):
+    """The Stork Agent uses self-signed TLS certificates over HTTPS, but the Kea
+    requires the valid credentials. The Stork Agent should send request, but get
+    rejection from the Kea CA."""
+    # install kea on the agent machine
+    agent.set_skip_tls_cert_verification()
+    agent.install_kea(tls_support=KeaTLSSupport.REQUIRE_CLIENT_CERT)
+
+    # login
+    r = server.api_post('/sessions', json=dict(useremail='admin', userpassword='admin'), expected_status=200)  # TODO: POST should return 201
+    assert r.json()['login'] == 'admin'
+
+    # get machine that automatically registered in the server and authorize it
+    m = _get_machines_and_authorize_them(server)[0]
+    # trig forward command to Kea over HTTPS
+    m = _get_machine_state(server, m['id'])
+
+    assert m['address'] == agent.mgmt_ip
+    assert m['apps'][0]['accessPoints'][0]['useSecureProtocol']
+
+    ca_svc_name = 'kea-ctrl-agent' if 'centos' in agent.name else 'isc-kea-ctrl-agent'
+    res = agent.run('journalctl -xeu ' + ca_svc_name)
+    assert 'TLS handshake with 127.0.0.1 failed with certificate verify failed' in res.stdout
+
+
+@pytest.mark.parametrize("agent, server", [('centos/8', 'ubuntu/18.04')])
+def test_communication_with_kea_over_secure_protocol_require_trusted_cert(agent, server):
+    """Check if Stork agent requires a trusted Kea cert if specific flag is not set.
+    In this test the Kea doesn't require TLS certificate on the client side."""
+    # install kea on the agent machine
+    agent.install_kea(tls_support=KeaTLSSupport.OPTIONAL_CLIENT_CERT)
+
+    # login
+    r = server.api_post('/sessions', json=dict(useremail='admin', userpassword='admin'), expected_status=200)  # TODO: POST should return 201
+    assert r.json()['login'] == 'admin'
+
+    # get machine that automatically registered in the server and authorize it
+    m = _get_machines_and_authorize_them(server)[0]
+    # trig forward command to Kea over HTTPS
+    m = _get_machine_state(server, m['id'])
+
+    assert m['address'] == agent.mgmt_ip
+    assert m['apps'][0]['accessPoints'][0]['useSecureProtocol']
+
+    ca_svc_name = 'kea-ctrl-agent' if 'centos' in agent.name else 'isc-kea-ctrl-agent'
+    res = agent.run('journalctl -xeu ' + ca_svc_name)
+    assert 'TLS handshake with 127.0.0.1 failed with sslv3 alert bad certificate' in res.stdout
