@@ -111,8 +111,7 @@ const routes: Routes = [
     },
     {
         path: 'users',
-        redirectTo: 'users/',
-        pathMatch: 'full',
+        component: UsersPageComponent,
         canActivate: [AuthGuard],
     },
     {
@@ -150,7 +149,7 @@ const routes: Routes = [
 ]
 
 @NgModule({
-    imports: [RouterModule.forRoot(routes)],
+    imports: [RouterModule.forRoot(routes, { relativeLinkResolution: 'legacy' })],
     exports: [RouterModule],
 })
 export class AppRoutingModule {}
